@@ -20,13 +20,16 @@ def add_current_root(url):
     return url
 
 class EntriesFeed(Feed):
-    
+    title_template = "cmsplugin_blog/feed_entries_title.html"
+    description_template = "cmsplugin_blog/feed_entries_description.html"
+
     def get_object(self, request, **kwargs):
         self.language_code = get_language_from_request(request)
         self.any_language = kwargs.get('any_language', None)
         self.language_namespace = ''
         if 'cmsplugin_blog.middleware.MultilingualBlogEntriesMiddleware' in settings.MIDDLEWARE_CLASSES:
             self.language_namespace = '%s:' % self.language_code
+        else:
             self.any_language = True
         return None
     
@@ -67,10 +70,12 @@ class EntriesFeed(Feed):
         return item.entry.pub_date
 
 class TaggedEntriesFeed(EntriesFeed):
+    title_template = "cmsplugin_blog/feed_tagged_title.html"
+    description_template = "cmsplugin_blog/feed_tagged_description.html"
     
     def get_object(self, request, **kwargs):
         super(TaggedEntriesFeed, self).get_object(request, **kwargs)
-        self.tag = kwargs.get('tag')  
+        self.tag = kwargs.get('tag')
         return None
     
     def title(self, obj):
@@ -93,4 +98,31 @@ class TaggedEntriesFeed(EntriesFeed):
         qs = super(TaggedEntriesFeed, self).get_queryset(obj)
         return Entry.tagged.with_any(self.tag, queryset=qs)
         
+class AuthorEntriesFeed(EntriesFeed):
+    title_template = "cmsplugin_blog/feed_author_title.html"
+    description_template = "cmsplugin_blog/feed_author_description.html"
 
+    def get_object(self, request, **kwargs):
+        super(AuthorEntriesFeed, self).get_object(request, **kwargs)
+        self.author = kwargs.get('author')
+        return None
+    
+    def title(self, obj):
+        title = super(AuthorEntriesFeed, self).title(obj)
+        return _(u'%(title)s by %(author)s') % {'title': title, 'author': self.author}
+    
+    def feed_url(self, obj):
+        if self.any_language:
+            return add_current_root(reverse('%sblog_rss_any_author' % self.language_namespace, kwargs={'author': self.author}))
+        return add_current_root(reverse('%sblog_rss_author' % self.language_namespace, kwargs={'author': self.author}))
+    
+    def link(self, obj):
+        return add_current_root(reverse('%sblog_archive_author' % self.language_namespace, kwargs={'author': self.author}))
+    
+    def description(self, obj):
+        description = super(AuthorEntriesFeed, self).description(obj)
+        return _(u'%(description)s by %(author)s') % {'description': description, 'author': self.author}
+    
+    def get_queryset(self, obj):
+        qs = super(AuthorEntriesFeed, self).get_queryset(obj)
+        return qs.filter(entrytitle__author__username=self.author)
